'''
用于打印多重嵌套列表元素的函数
'''
def func1(st,isneed=False,level=0):
        # 循环查询列表元素，找出其中的属于列表的元素
        for each_st in st:
                if isinstance(each_st,list):
                        func1(each_st,isneed,level+1)
                else:
                        #打印指定的缩进
                        if isneed:
                                for i in range(level):
                                        print("\t",end='')
                        print(each_st)
			



from distutils.core import  setup


setup(

    name   = 'pysproject1',
    version = '1.2.0',
    py_modules = ['pysproject1'],
    author = 'pys2moving',
    author_email = '1029384008@qq.com',
    url = 'https://github.com/Wison2moving',
    description = 'A simple printer of nested list',
    
    )
